import { Meta, Canvas, Controls } from "@storybook/blocks";
import * as Storyname from "./slider.stories";

<Meta of={Storyname} name="Docs" />

# Slider - Intro

It is recommended to have a look at the documentation of the slider component before the integration.

### Important notes

During the integration, please take care in ensuring that no additional/superfluous grid elements are wrapped outside of the
slider element. The slider itself does not have any default margins or paddings, these have to be added either in wrapping
elements or with the help of utility classes, for example: `ux-u-margin-vertical-30`.

**_This is a complex component and a visual check after the integration has to be performed_**

<a
    class="ux-button"
    href="https://docs.ux.trumpf.com/uxuicore/main/?path=/docs/content-slider--docs"
    target="_blank"
>
    <span>View ux-slider component documentation</span>
</a>

## Common Slider Issues and how to solve them

<table style={{ width: "100%" }}>
    <colgroup>
        <col style={{ width: "20%" }}></col>
        <col style={{ width: "80%" }}></col>
    </colgroup>
    <thead>
        <tr>
            <th>Issue</th>
            <th>Possible Cause and solution</th>
        </tr>
    </thead>
    <tbody>
        <tr>
            <td>
                The height of the slider arrows in relation to the slides is not
                correct
            </td>
            <td>
                To align the arrows height to the center of the image of the
                slides use the prop
                <b> arrows-follow-img</b>, this should align the arrows to the center
                of the image of the slider. It is also possible to pass a css selector
                as the value of the prop, an the arrows will be aligned with the
                center of the found selector. The element target of the selector
                needs to be wrapped by the <b>ux-slider-slide</b> component, it can
                not be a wrapping element. For example: <b>
                    arrows-follow-img="ux-slider-wrapper"
                </b> is not a valid usage of the attribute.
            </td>
        </tr>
        <tr>
            <td>The dimensions of the slider are too small</td>
            <td>
                Check if the slider component is not placed inside a grid
                element, or any other wrapping element that could limit its
                dimensions.
            </td>
        </tr>
        <tr>
            <td>
                The spacings between the elements in the slider seem incorrect
            </td>
            <td>
                The slider element does not provide default spacing. If the
                spacings between elements are too big, check for spacing utility
                classes among the content of the slider.
            </td>
        </tr>
        <tr>
            <td>The pagination is not displayed correctly</td>
            <td>
                If the <b>ux-slider-pagination</b> component is being used with
                the attribute <b>anchor-pagination</b>, every slide, or content
                of the slide, need to include a div with the class{" "}
                <b>ux-slider-pagination-anchor</b> in order for the pagination
                to correctly take its position.
            </td>
        </tr>
    </tbody>
</table>

## Slider type infos

### Product Slider Zoom

To create this slider, use as the slides the `ux-iws-slider-slide-zoomable` component.
_WARING_ so far, this slider only works if the content of the slides is the block hero with `block-zoom-image`
and `btn-zoom-wrapper` elements.

### Contact Slider

Pass the following classes to each `ux-slider-slide` component: `contact-card slider-slide u-clearfix`.

### Quote List Slider

Pass these classes to all all `ux-slider-slide` components: `quote-list-single noImg u-clearfix`

### Product Slider

Pass the following classes to every `ux-slider-slide` component: `block block-product-slider-entry slider-slide`

### Triple Slider

Pass the following classes to every `ux-slider-slide` component: `block-product-slider-entry`

### Notification Slider

Pass the class `notification-slider-entry` to every slide
